@@ -31,8 +31,6 @@ using namespace LibImportWizard;
 
 AbstractImporter::AbstractImporter(QObject *parent)
     : QObject(parent)
-    , mAbstractDisplayInfo(nullptr)
-    , mParentWidget(nullptr)
 {
 }
 
